// Javascript functions used by all of the html files.
// These are loaded by the line
// <script language="javascript" src="functions.js"></script>
// in the header.

var gCssSize = "cssSize";
var gSaveLocation = "SaveLocation";


function Timer(anim)
{
    anim.curPicture++;
    if (anim.curPicture == anim.pictures.length)
    {
        if (anim.loop)
        {
            anim.curPicture = 0
        }
        else
        {
            anim.curPicture--;
            clearInterval(anim.timerId);
        }
    }

    document.images[0].src = anim.pictures[anim.curPicture];
}


// This function plays a sound on HTML5 browsers and IE.  The 
// name is the path to the .wav file.  If loop is set to "true"
// it will repeat the sound on IE.  Firefox currently has a 
// bug where the loop command is ignored.  When that is fixed
// the loop should work there as well.
// https://bugzilla.mozilla.org/show_bug.cgi?id=449157
function PlaySound(name, loop)
{
    var loop5 = "false";
    var loopbg = "1";

    if (loop == "true")
    {
        loop5 = "true";
        loopbg = "infinite";
    }

    document.write("<audio src=" + name + " autoplay='true' loop='" + loop5 + "'>");
    document.write("<bgsound src=" + name + " loop='" + loopbg + "' />");
    document.write("</audio>");
}


function AddCss()
{
    var cssFile = "_style.css";
    var size = readVar(gCssSize);

    if (size > 0)
    {
        cssFile = "_style2.css";
    }

    document.write("<link href=\"" + cssFile + "\" rel=\"stylesheet\" type=\"text/css\" />");
}


function ChooseSize()
{
    var size = 0;

    if (typeof (gameLargeScreenWidth) != "undefined" && typeof (gameLargeScreenHeight) != "undefined")
    {
        if (screen.width >= gameLargeScreenWidth && screen.height >= gameLargeScreenHeight)
        {
            size = 1;
        }
    }

    setVar(gCssSize, size);
    return size;
}



//<area shape="rect" coords="80,43,552,405" onclick="return foo();" href="intro1.html" title="Goto 1" />

function AddArea(x1, y1, x2, y2, onclick, href, title)
{
    var size = readVar(gCssSize);
    var str;

    if (size > 0 && typeof(gameScaleFactor) != "undefined")
    {
        x1 *= gameScaleFactor;
        y1 *= gameScaleFactor;
        x2 *= gameScaleFactor;
        y2 *= gameScaleFactor;
    }

    str = "<area shape=\"rect\" coords=\"" + x1 + "," + y1 + "," + x2 + "," + y2 + "\" ";
    
    if (onclick != "#")
    {
        str += "onclick=\"" + onclick + "\" ";
    }

    str += "href=\"" + href + "\" title=\"" + title + "\" />";

    document.write(str);
}


function CheckIfSaveExists()
{
    var page = readString(gSaveLocation);
    if (page == 0)
    {
        return false;
    }
    else
    {
        return true;
    }
}


function SaveState(page)
{
    if (typeof (page) == "undefined")
    {
        page = document.URL;
    }

    setString(gSaveLocation, page);

    for (var val in gameVars)
    {
        var from = gameVars[val];
        var to = from.concat("_SaveState");
        setVar(to, readVar(from));
    }

    return false;
}

function RestoreState()
{
    for (var val in gameVars)
    {
        var to = gameVars[val];
        var from = to.concat("_SaveState");
        setVar(to, readVar(from));
    }

    var page = readString(gSaveLocation);
    window.location = page;

    return false;
}



// This function can replace simple "check" files. Give it the variable and a check value, and it 
// will navigate to the link1 if the variable is greater than the check.  It wil
// navigate to link2 if the variable is less than or equal to the check.
// ie:  Choose('cinema', 0, 'beenthere.html', 'cinema1.html');
function Choose(name, check, link1, link2)
{
    var val = readVar(name);
    if (val > check)
    {
        window.location = link1;
    }
    else
    {
        window.location = link2;
    }

    return false;
}



//--------------------------------------------------------//
// Cookie (variable) functions
//
// These functions are used for storing and changing 
// variables in the site.

// This function deletes a cookie
function deleteVar(name) 
{
    document.cookie = name + "=; expires=Thu, 01-Jan-70 00:00:01 GMT" + "; path=/";
} 

// This function creates a cookie (if necessary) and sets its value
function setVar(name, value, expires)
{
    if (expires == null)
    {
        var days = 30; // Number of days to keep the cookies

        expires = new Date();
        expires.setTime(expires.getTime() + (days * 24 * 60 * 60 * 1000));
    }

    document.cookie = name + "=" + escape(value) + "; path=/" + ((expires == null) ? "" : "; expires=" + expires.toGMTString()); 
}

function initVars()
{
    for (var val in gameVars)
    {
        setVar(gameVars[val], 0);
    }

    ChooseSize();
}

// This function reads the cookie and returns its value as a number.  
// If the cookie doesn't exist or isn't a number, this returns 0.
function readVar(name)
{
    var fullName = name + "=";
    var val = 0;
    var strings = document.cookie.split(';');
    for(var i=0; i < strings.length; i++) 
    {
	    var str = strings[i];
	    while (str.charAt(0)==' ')
	        str = str.substring(1, str.length);
	    if (str.indexOf(fullName) == 0) 
	        val = parseInt(str.substring(fullName.length, str.length));
	    if (isNaN(val))
	        val = 0;    
    }
	return val;
}

// This function creates a cookie (if necessary) and sets its (string) value
function setString(name, value, expires)
{
    if (expires == null)
    {
        var days = 30; // Number of days to keep the cookies

        expires = new Date();
        expires.setTime(expires.getTime() + (days * 24 * 60 * 60 * 1000));        
    }

    document.cookie = name + "=" + value + "; path=/" + ((expires == null) ? "" : "; expires=" + expires.toGMTString());
}

// This function reads the cookie and returns its value as a string.  
function readString(name)
{
    var fullName = name + "=";
    var val = 0;
    var strings = document.cookie.split(';');
    for (var i = 0; i < strings.length; i++)
    {
        var str = strings[i];
        while (str.charAt(0) == ' ')
            str = str.substring(1, str.length);
        if (str.indexOf(fullName) == 0)
            val = str.substring(fullName.length, str.length);
    }
    return val;
}


// If the variable's value is 0, this sets it to 1.
// If the variable's value is anything else, this sets it to 0.
function varToggle(name)
{
    var val = readVar(name);
    if (val == 0)
    {
        val = 1;
    }
    else
    {
        val = 0;
    }
    setVar(name, val);
}

// This function adds 1 to a variable's value
function varPlus1(name)
{
    var val = readVar(name);
    val += 1;
    setVar(name, val);
}

// This function adds 1 to a variable's value if the second variable is 0
function varPlus1If0(name, checkName)
{
    var val = readVar(name);
    var check = readVar(checkName);
    if (check == 0)
    {
        val += 1;
        setVar(name, val);
    }
}

// This function adds an arbitrary amount to the variable's value
function varPlus(name, amount)
{
    var val = readVar(name);
    val += amount;
    setVar(name, val);
}


// This function subtracts 1 from a variable's value. 
// If the value would have gone negative, it sets the value to 0.
function varMinus1(name)
{
    var val = readVar(name);
    if (val > 1)
        val -= 1;
    else
        val = 0;        
    setVar(name, val);
}

// This function subtracts an arbitrary amount from a variable's value. 
// If the value would have gone negative, it sets the value to 0.
function varMinus(name, amount)
{
    var val = readVar(name);
    if (val > amount)
        val -= amount;
    else
        val = 0;        
    setVar(name, val);
}


// The next three functions are "bitwise."  They are used for 
// packing multiple "yes/no" variables into one cookie.
// The index starts from 0.
function varSetBit(name, index)
{
    var val = readVar(name);
    var mask = 1 << index;
    val = val | mask;
    setVar(name, val);
}

function varClearBit(name, index)
{
    var val = readVar(name);
    var mask = ~(1 << index);
    val = val & mask;
    setVar(name, val);
}

function varReadBit(name, index)
{
    var val = readVar(name);
    val = (val >> index) & 0x01;
    return val;
}


// This is a debugging function.  Use it to print the value of a variable 
//on the screen.
function outputVar(name)
{
    var val = readVar(name);
    //document.write("<p>" + name + " = " + val + "</p>");  

    document.write("<p>" + name + " = " + val + " <a onclick=\"varMinus1('" + name + "');\" href='#'>sub</a> <a onclick=\"varPlus1('" + name + "');\" href='#'>add</a></p>");    
}

// This is a function for outputing a string centered on the screen.  
//It is typically used for displaying the score.
function outputString(string)
{
    document.write("<div align='center'><p>" + string + "</p></div>");
}


//--------------------------------------------------------//
// Navigation disabling functions
// 
// These functions are used for disabling various forms
// of navigation on the site (especially pressing the
// back button).  


// This is the entry point for all navigation disabling functions.
// It is called from each page's body onload.
function disallowNav()
{

    var allowNav = 0;
    
    if (typeof (gameAllowNav) != "undefined")
    {
        allowNav = gameAllowNav;
    }

    if (!allowNav)
    {
        document.oncontextmenu = blockContextMenu;
        document.onkeydown = blockKeyPresses;

        // This part works for IE, but not Firefox
        undoBack();
        // This extra part is need for Firefox
        window.onload = window.onload; undoBack();
        window.onpageshow = function (evt) { if (evt.persisted) undoBack() };
        window.onunload = function () { void (0) };
    }
}


// If the user goes back, drive him forward again
function undoBack()
{
    window.history.forward();
}

// Disallow the context menu
function blockContextMenu()
{
	event.cancelBubble = true
   	event.returnValue = false;
  	return false;
}

// This is kind of overkill, but it will block the user
// from hitting backspace or F5
function blockKeyPresses() 
{
    var keyBackspace = 8;
    var keyF5 = 116;
    
	if ((event.keyCode == keyBackspace) || (event.keyCode == keyF5)) 
   	{
   	    event.keyCode = 0;
   	    event.returnValue = false;
   	}
}



//--------------------------------------------------------//
// Debug Function
// 
// This function is used for debugging the game.
// To make use of it, go into your _game.js file and set
// "gameDoDebug" to 1. You will also have needed to set your 
// game variables into an array called gameVars.
// For example, the top lines of your _game.js would look like this:
//var gameVars = ["happy", "angry", "difficulty"];
//var gameDoDebug = 1;

function debug()
{
    var doDebug = 0;

    if (typeof (gameDoDebug) != "undefined")
    {
        doDebug = gameDoDebug;
    }

    if (doDebug)
    {
        for (var val in gameVars)
        {
            outputVar(gameVars[val]);
        }
    }
}

//--------------------------------------------------------//
// ShowScore Function
// 
// This function is used for showing the score in the game.
// It will only work if you have a gameShowScore() function 
// in your _game.js file. 

function showScore()
{
    if (typeof (gameShowScore) != "undefined")
    {
        gameShowScore();
    }
}
